inheritanceConstructor property
Specifies the named constructor of the annotated class to be used in the
generated class, e.g. '', '_internal', etc.
Note: The template you use must support this option, such as the
default_model_template template.
Implementation
final String? inheritanceConstructor;